@@ -6,6 +6,7 @@ import string
 import wave
 from math import floor
 from . import tracker
+import re
 
 def main():
     """Parses, opens and extracts samples from a tracker module file."""
@@ -34,9 +35,15 @@ def main():
                 sample["name"] = "".join(filter(lambda x: x in set(string.printable), sample["name"]))
                 if sample["name"] != "" and not sample["name"].isspace():
                     sample_file_name += " - " + sample["name"].strip()
-                print("[Exporting Sample] " + sample_file_name)
+
+                # remove chars unfriendly to some filesystems (NTFS, etc)
+                # cracktro musicians love to include fancy chars in their sample names
+                sample_file_name = re.sub(r"[^\w\s\d-]", "_", sample_file_name)
+
                 sample_file_name += ".wav"
 
+                print("[Exporting Sample] " + sample_file_name)
+
                 output_path = output_dir / sample_file_name
                 out = wave.open(str(output_path), "wb")
                 out.setnchannels(1)
@@ -46,12 +53,13 @@ def main():
                 out.close()
 
                 if sample["loop_type"] != tracker.LoopType.OFF:
+                    # construct sample chunk
                     smpl_chunk = b"smpl"
                     # chunk size
                     smpl_chunk += int(36 + (1 * 24) + 0).to_bytes(4, "little")
                     # manufacturer & product
                     smpl_chunk += bytes(8)
-                    # saample period
+                    # sample period
                     smpl_chunk += int(floor(1000000000 / sample["rate"])).to_bytes(4, "little")
 
                     # TODO: figure me out
